@@ -36,7 +36,7 @@ devnet_spot_market_configs: list[SpotMarketConfig] = [
         market_index=1,
         oracle=Pubkey.from_string("BAtFj4kQttZRVep3UZS2aZRDixkGYgWsbqTBVDbnSsPF"),
         oracle_source=OracleSource.PythPull(),  # type: ignore
-        mint=WRAPPED_SOL_MINT,
+        mint=Pubkey.from_string("So11111111111111111111111111111111111111112"),
     ),
     SpotMarketConfig(
         symbol="BTC",
@@ -46,14 +46,14 @@ devnet_spot_market_configs: list[SpotMarketConfig] = [
         mint=Pubkey.from_string("3BZPwbcqB5kKScF3TEXxwNfx5ipV13kbRVDvfVp5c6fv"),
     ),
     SpotMarketConfig(
-        symbol="PYUSD",
+        symbol="Default Market Name",
         market_index=3,
         oracle=Pubkey.from_string("HpMoKp3TCd3QT4MWYUKk2zCBwmhr5Df45fB6wdxYqEeh"),
         oracle_source=OracleSource.PythPull(),  # type: ignore
         mint=Pubkey.from_string("GLfF72ZCUnS6N9iDJw8kedHzd6WFVf3VbpwdKKy76FRk"),
     ),
     SpotMarketConfig(
-        symbol="BONK",
+        symbol="Bonk",
         market_index=4,
         oracle=Pubkey.from_string("GojbSnJuPdKDT1ZuHuAM5t9oz6bxTo1xhUKpTua2F72p"),
         oracle_source=OracleSource.PythPull(),  # type: ignore
@@ -70,25 +70,33 @@ devnet_spot_market_configs: list[SpotMarketConfig] = [
         symbol="USDC",
         market_index=6,
         oracle=Pubkey.from_string("En8hkHLkRe9d9DraYmBTrus518BvmVH448YcvmrFM6Ce"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle_source=OracleSource.PythStableCoinPull(),  # type: ignore
         mint=Pubkey.from_string("8zGuJQqwhZafTah7Uc7Z4tXRnguqkn5KLFAP8oV6PHe2"),
     ),
+    SpotMarketConfig(
+        symbol="PLXY",
+        market_index=7,
+        oracle=Pubkey.from_string("4wFrjUQHzRBc6qjVtMDbt28aEVgn6GaNiWR6vEff4KxR"),
+        oracle_source=OracleSource.Prelaunch(),  # type: ignore
+        mint=Pubkey.from_string("2vVfXmcWXEaFzp7iaTVnQ4y1gR41S6tJQQMo1S5asJyC"),
+    ),
 ]
 
+
 mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="USDC",
         market_index=0,
-        oracle=Pubkey.from_string("En8hkHLkRe9d9DraYmBTrus518BvmVH448YcvmrFM6Ce"),
-        oracle_source=OracleSource.PythStableCoinPull(),  # type: ignore
+        oracle=Pubkey.from_string("9VCioxmni2gDLv11qufWzT3RDERhQE4iY5Gf7NTfYyAV"),
+        oracle_source=OracleSource.PythLazerStableCoin(),  # type: ignore
         mint=Pubkey.from_string("EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v"),
     ),
     SpotMarketConfig(
         symbol="SOL",
         market_index=1,
-        oracle=Pubkey.from_string("BAtFj4kQttZRVep3UZS2aZRDixkGYgWsbqTBVDbnSsPF"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
-        mint=WRAPPED_SOL_MINT,
+        oracle=Pubkey.from_string("3m6i4RFWEDw2Ft4tFHPJtYgmpPe21k56M3FHeWYrgGBz"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
+        mint=Pubkey.from_string("So11111111111111111111111111111111111111112"),
     ),
     SpotMarketConfig(
         symbol="mSOL",
@@ -100,8 +108,8 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="wBTC",
         market_index=3,
-        oracle=Pubkey.from_string("9Tq8iN5WnMX2PcZGj4iSFEAgHCi8cM6x8LsDUbuzq8uw"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("fqPfDa6uQr9ndMvwaFp4mUBeUrHmLop8Jxfb1XJNmVm"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("3NZ9JMVBmGAqocybic2c7LQCJScmgsAZ6vQqTDzcqmJh"),
     ),
     SpotMarketConfig(
@@ -114,8 +122,8 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="USDT",
         market_index=5,
-        oracle=Pubkey.from_string("BekJ3P5G3iFeC97sXHuKnUHofCFj9Sbo7uyF2fkKwvit"),
-        oracle_source=OracleSource.PythStableCoinPull(),  # type: ignore
+        oracle=Pubkey.from_string("JDKJSkxjasBGL3ce1pkrN6tqDzuVUZPWzzkGuyX8m9yN"),
+        oracle_source=OracleSource.PythLazerStableCoin(),  # type: ignore
         mint=Pubkey.from_string("Es9vMFrzaCERmJfrF4H2FYD4KCoNkY11McCe8BenwNYB"),
     ),
     SpotMarketConfig(
@@ -128,8 +136,8 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="PYTH",
         market_index=7,
-        oracle=Pubkey.from_string("GqkCu7CbsPVz1H6W6AAHuReqbJckYG59TXz7Y5HDV7hr"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("6Sfx8ZAt6xaEgMXTahR6GrT7oYB6nFBMoVyCmMyHmeJV"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("HZ1JovNiVvGrGNiiYvEozEVgZ58xaU3RKwX8eACQBCt3"),
     ),
     SpotMarketConfig(
@@ -142,50 +150,50 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="JTO",
         market_index=9,
-        oracle=Pubkey.from_string("Ffq6ACJ17NAgaxC6ocfMzVXL3K61qxB2xHg6WUawWPfP"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("CGCz4mB8NsDddCq6BZToRUDUuktzsAfpKYh6ATgyyCGF"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("jtojtomepa8beP8AuQc6eXt5FriJwfFMwQx2v2f9mCL"),
     ),
     SpotMarketConfig(
         symbol="WIF",
         market_index=10,
-        oracle=Pubkey.from_string("6x6KfE7nY2xoLCRSMPT1u83wQ5fpGXoKNBqFjrCwzsCQ"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("4QXWStoyEErTZFVsvKrvxuNa6QT8zpeA8jddZunSGvYE"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("EKpQGSJtjMFqKZ9KQanSqYXRcF8fBopzLHYxdM65zcjm"),
     ),
     SpotMarketConfig(
         symbol="JUP",
         market_index=11,
-        oracle=Pubkey.from_string("AwqRpfJ36jnSZQykyL1jYY35mhMteeEAjh7o8LveRQin"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("DXqKSHyhTBKEW4qgnL7ycbf3Jca5hCvUgWHFYWsh4KJa"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("JUPyiwrYJFskUPiHa7hkeR8VUtAeFoSYbKedZNsDvCN"),
     ),
     SpotMarketConfig(
-        symbol="RNDR",
+        symbol="RENDER",
         market_index=12,
-        oracle=Pubkey.from_string("8TQztfGcNjHGRusX4ejQQtPZs3Ypczt9jWF6pkgQMqUX"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("97EqsAGbTnShB7oYWAFFCVVAx8PWXgDYDhcpm99izNQ4"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("rndrizKT3MK1iimdxRdWabcF7Zg7AR5T4nud4EkHBof"),
     ),
     SpotMarketConfig(
         symbol="W",
         market_index=13,
-        oracle=Pubkey.from_string("4HbitGsdcFbtFotmYscikQFAAKJ3nYx4t7sV7fTvsk8U"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("CsFUXiA5dM4eCKjVBBy8tXhXzDkDRNoYjU5rjpHyfNEZ"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("85VBFQZC9TZkfaptBWjvUw7YbZjy52A6mjtPGjstQAmQ"),
     ),
     SpotMarketConfig(
         symbol="TNSR",
         market_index=14,
-        oracle=Pubkey.from_string("13jpjpVyU5hGpjsZ4HzCcmBo85wze4N8Au7U6cC3GMip"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("EX6r1GdfsgcUsY6cQ6YsToV4RGsb4HKpjrkokK2DrmsS"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("TNSRxcUxoT9xBG3de7PiJyTDYu7kskLqcpddxnEJAS6"),
     ),
     SpotMarketConfig(
         symbol="DRIFT",
         market_index=15,
-        oracle=Pubkey.from_string("23KmX7SNikmUr2axSCy6Zer7XPBnvmVcASALnDGqBVRR"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("5VJou4ufN2vE11zyZUaLsKLTXhyzCTgiq6QDsts2YnnD"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("DriFtupJYLTosbwoN8koMbEYSx54aFAVLddWsbksjwg7"),
     ),
     SpotMarketConfig(
@@ -205,8 +213,8 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="USDY",
         market_index=18,
-        oracle=Pubkey.from_string("BPTQgHV4y2x4jvKPPkkd9aS8jY7L3DGZBwjEZC8Vm27o"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("9PgHM68FNGDK6nHb29ERDBcFrV6gNMD8LyUqwxbyyeb2"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("A1KLoBrKBde8Ty9qtNQUtq3C2ortoC3u7twggz7sEto6"),
     ),
     SpotMarketConfig(
@@ -219,29 +227,29 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="POPCAT",
         market_index=20,
-        oracle=Pubkey.from_string("H3pn43tkNvsG5z3qzmERguSvKoyHZvvY6VPmNrJqiW5X"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("C5fiAmQyjdfDR4EGepZqnEL3fJwMBav5yoAk6XyKMF6u"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("7GCihgDB8fe6KNjn2MYtkzZcRjQy3t9GHdC8uHYmW2hr"),
     ),
     SpotMarketConfig(
         symbol="CLOUD",
         market_index=21,
-        oracle=Pubkey.from_string("FNFejcXENaPgKaCTfstew9vSSvdQPnXjGTkJjUnnYvHU"),
-        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        oracle=Pubkey.from_string("9Ennia27iT83kNAk3JtRKxSMzuCzsVtT4MzuxpE7anME"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("CLoUDKc4Ane7HeQcPpE3YHnznRxhMimJ4MyaUqyHFzAu"),
     ),
     SpotMarketConfig(
         symbol="PYUSD",
         market_index=22,
-        oracle=Pubkey.from_string("HpMoKp3TCd3QT4MWYUKk2zCBwmhr5Df45fB6wdxYqEeh"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("5QZMnsyndmphvZF4BNgoMHwVZaREXeE2rpBoCPMxgCCd"),
+        oracle_source=OracleSource.PythLazerStableCoin(),  # type: ignore
         mint=Pubkey.from_string("2b1kV6DkPAnxd5ixfnxCpjxmKwqjjaYmCZfHsFu24GXo"),
     ),
     SpotMarketConfig(
         symbol="USDe",
         market_index=23,
-        oracle=Pubkey.from_string("BXej5boX2nWudwAfZQedo212B9XJxhjTeeF3GbCwXmYa"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("5uR6oza6teuMRpjsbMi9fDhCDid2hoYdRBiLW7WzcK54"),
+        oracle_source=OracleSource.PythLazerStableCoin(),  # type: ignore
         mint=Pubkey.from_string("DEkqHyPN7GMRJ5cArtQFAWefqbZb33Hyf6s5iCwjEonT"),
     ),
     SpotMarketConfig(
@@ -261,14 +269,14 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="MOTHER",
         market_index=26,
-        oracle=Pubkey.from_string("56ap2coZG7FPWUigVm9XrpQs3xuCwnwQaWtjWZcffEUG"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("469WQgfJ6AJ3eJ8FUcdhiZawf7yNChA3hseTSyhFatHZ"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("3S8qX1MsMqRbiwKg2cQyx7nis1oHMgaCuc9c4VfvVdPN"),
     ),
     SpotMarketConfig(
         symbol="cbBTC",
         market_index=27,
-        oracle=Pubkey.from_string("486kr3pmFPfTsS4aZgcsQ7kS4i9rjMsYYZup6HQNSTT4"),
+        oracle=Pubkey.from_string("9jPy6EHpLkXaMdvfkoVnRnSdJoQysQDKKj3bW5Amz4Ci"),
         oracle_source=OracleSource.PythPull(),  # type: ignore
         mint=Pubkey.from_string("cbbtcf3aa214zXHbiAZQwf4122FBYbraNdFqgw4iMij"),
     ),
@@ -289,57 +297,204 @@ mainnet_spot_market_configs: list[SpotMarketConfig] = [
     SpotMarketConfig(
         symbol="ME",
         market_index=30,
-        oracle=Pubkey.from_string("FLQjrmEPGwbCKRYZ1eYM5FPccHBrCv2cN4GBu3mWfmPH"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("BboTg1yT114FQkqT6MM3P3G3CcCktuM2RePgU8Gr3K4A"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("MEFNBXixkEbait3xn9bkm8WsJzXtVsaJEn4c8Sam21u"),
     ),
     SpotMarketConfig(
         symbol="PENGU",
         market_index=31,
-        oracle=Pubkey.from_string("7vGHChuBJyFMYBqMLXRzBmRxWdSuwEmg8RvRm3RWQsxi"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("4A3KroGPjZxPAeBNF287V3NyRwV2q8iBi1vX7kHxTCh7"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("2zMMhcVQEXDtdE6vsFS7S7D5oUodfJHE8vd1gnBouauv"),
     ),
     SpotMarketConfig(
-        symbol="BONK",
+        symbol="Bonk",
         market_index=32,
-        oracle=Pubkey.from_string("GojbSnJuPdKDT1ZuHuAM5t9oz6bxTo1xhUKpTua2F72p"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("BERaNi6cpEresbq6HC1EQGaB1H1UjvEo4NGnmYSSJof4"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("DezXAZ8z7PnrnRJjz3wXBoRgixCa6xjnB7YaB1pPB263"),
     ),
     SpotMarketConfig(
-        symbol="JLP",
+        symbol="JLP-1",
         market_index=33,
-        oracle=Pubkey.from_string("5Mb11e5rt1Sp6A286B145E4TmgMzsM2UX9nCF2vas5bs"),
+        oracle=Pubkey.from_string("3ZLn5XDgSLWhTk2NjqAU44cPkSeC5JAhW5o6w5Nz4p8R"),
         oracle_source=OracleSource.PythPull(),  # type: ignore
         mint=Pubkey.from_string("27G8MtK7VtTcCHkpASjSDdkWWYfoqT6ggEuKidVJidD4"),
     ),
     SpotMarketConfig(
-        symbol="USDC",
+        symbol="USDC-1",
         market_index=34,
-        oracle=Pubkey.from_string("En8hkHLkRe9d9DraYmBTrus518BvmVH448YcvmrFM6Ce"),
-        oracle_source=OracleSource.PythStableCoinPull(),  # type: ignore
+        oracle=Pubkey.from_string("9VCioxmni2gDLv11qufWzT3RDERhQE4iY5Gf7NTfYyAV"),
+        oracle_source=OracleSource.PythLazerStableCoin(),  # type: ignore
         mint=Pubkey.from_string("EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v"),
     ),
     SpotMarketConfig(
         symbol="AI16Z",
         market_index=35,
-        oracle=Pubkey.from_string("3gdGkrmBdYR7B1MRRdRVysqhZCvYvLGHonr9b7o9WVki"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("3BGheQVvYtBNpBKSUXSTjpyKQc3dh8iiwT91Aiq7KYCU"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("HeLp6NuQkmYB4pYWo2zYs22mESHXPQYzXbB8n4V98jwC"),
     ),
     SpotMarketConfig(
         symbol="TRUMP",
         market_index=36,
-        oracle=Pubkey.from_string("AmSLxftd19EPDR9NnZDxvdStqtRW7k9zWto7FfGaz24K"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("FPQjZYvHRGy51guJ77p7n9u9b8eo1ktKRc2D2g5Vysth"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("6p6xgHyF7AeE6TZkSmFsko444wqoP15icUSqi2jfGiPN"),
     ),
     SpotMarketConfig(
         symbol="MELANIA",
         market_index=37,
-        oracle=Pubkey.from_string("28Zk42cxbg4MxiTewSwoedvW6MUgjoVHSTvTW7zQ7ESi"),
-        oracle_source=OracleSource.PythPull(),  # type: ignore
+        oracle=Pubkey.from_string("3RgNWYYcZCKf5uZfriK8ASUbGQErhH6YbpdvZQ7ZKDCf"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
         mint=Pubkey.from_string("FUAfBo2jgks6gB4Z4LfZkqSZgzNucisEHqnNebaRxM1P"),
     ),
+    SpotMarketConfig(
+        symbol="AUSD",
+        market_index=38,
+        oracle=Pubkey.from_string("8FZhpiM8n3mpgvENWLcEvHsKB1bBhYBAyL4Ypr4gptLZ"),
+        oracle_source=OracleSource.PythStableCoinPull(),  # type: ignore
+        mint=Pubkey.from_string("AUSD1jCcCyPLybk1YnvPWsHQSrZ46dxwoMniN4N2UEB9"),
+    ),
+    SpotMarketConfig(
+        symbol="FARTCOIN",
+        market_index=39,
+        oracle=Pubkey.from_string("2sZomfWMDuQLcFak3nuharXorHrZ3hK8iaML6ZGSHtso"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
+        mint=Pubkey.from_string("9BB6NFEcjBCtnNLFko2FqVQBq8HHM13kCyYcdQbgpump"),
+    ),
+    SpotMarketConfig(
+        symbol="JitoSOL-3",
+        market_index=40,
+        oracle=Pubkey.from_string("Fqv8vT5fdjvBbHd5k4B4ZvnXLH6bbdKP8cMv93ybCP8W"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("J1toso1uCk3RLmjorhTtrVwY9HJ7X8V9yYac6Y7kGCPn"),
+    ),
+    SpotMarketConfig(
+        symbol="PT-fragSOL-10JUL25",
+        market_index=41,
+        oracle=Pubkey.from_string("CLjvwowzQ2L9PrmXA6zqbamxLVeDY9vE87aBxMZLJLoY"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("8adRViFUNTe3yexj2gbQtx929zBJtWJRM8TeTzYbQBgx"),
+    ),
+    SpotMarketConfig(
+        symbol="PT-kySOL-15JUN25-3",
+        market_index=42,
+        oracle=Pubkey.from_string("G4FdLzuezfaJxBd8eChuw1NU4Sq3n1rasGTwSh7dXegN"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("FxT7bPGvkS5jKF2vgnJ16MciHqtsNqxbcWTfFg7L136h"),
+    ),
+    SpotMarketConfig(
+        symbol="PT-dSOL-30JUN25-3",
+        market_index=43,
+        oracle=Pubkey.from_string("BR4NCRe2R8shvDAskUt6HE3n8Ej8HdMnVqshLz97BMm9"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("8H3tZ7WcgYPKEQ7fCCAFQuaNqKdMH1EtBp2ovUPpRK3k"),
+    ),
+    SpotMarketConfig(
+        symbol="JTO-3",
+        market_index=44,
+        oracle=Pubkey.from_string("DPvVSQYhZXQ2ygfT2Qjdg6iyeQVAyiz8okj88YRjy6NN"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("jtojtomepa8beP8AuQc6eXt5FriJwfFMwQx2v2f9mCL"),
+    ),
+    SpotMarketConfig(
+        symbol="zBTC",
+        market_index=45,
+        oracle=Pubkey.from_string("CN9QvvbGQzMnN8vJaSek2so4vFnTqgJDFrdJB8Y4tQfB"),
+        oracle_source=OracleSource.PythPull(),  # type: ignore
+        mint=Pubkey.from_string("zBTCug3er3tLyffELcvDNrKkCymbPWysGcWihESYfLg"),
+    ),
+    SpotMarketConfig(
+        symbol="ZEUS",
+        market_index=46,
+        oracle=Pubkey.from_string("8cH72H3vqYPArV9QvkYJkwzTdsdNPPgVPrusz9sMmgNN"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
+        mint=Pubkey.from_string("ZEUS1aR7aX8DFFJf5QjWj2ftDDdNTroMNGo8YoQm3Gq"),
+    ),
+    SpotMarketConfig(
+        symbol="USDC-4",
+        market_index=47,
+        oracle=Pubkey.from_string("9VCioxmni2gDLv11qufWzT3RDERhQE4iY5Gf7NTfYyAV"),
+        oracle_source=OracleSource.PythLazerStableCoin(),  # type: ignore
+        mint=Pubkey.from_string("EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v"),
+    ),
+    SpotMarketConfig(
+        symbol="USDT-4",
+        market_index=48,
+        oracle=Pubkey.from_string("JDKJSkxjasBGL3ce1pkrN6tqDzuVUZPWzzkGuyX8m9yN"),
+        oracle_source=OracleSource.PythLazerStableCoin(),  # type: ignore
+        mint=Pubkey.from_string("Es9vMFrzaCERmJfrF4H2FYD4KCoNkY11McCe8BenwNYB"),
+    ),
+    SpotMarketConfig(
+        symbol="SOL-2",
+        market_index=49,
+        oracle=Pubkey.from_string("3PiwrLLyiuWaxS7zJL5znGR9iYD3KWubZThdQzsCdg2e"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("So11111111111111111111111111111111111111112"),
+    ),
+    SpotMarketConfig(
+        symbol="JitoSOL-2",
+        market_index=50,
+        oracle=Pubkey.from_string("Fqv8vT5fdjvBbHd5k4B4ZvnXLH6bbdKP8cMv93ybCP8W"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("J1toso1uCk3RLmjorhTtrVwY9HJ7X8V9yYac6Y7kGCPn"),
+    ),
+    SpotMarketConfig(
+        symbol="JTO-2",
+        market_index=51,
+        oracle=Pubkey.from_string("DPvVSQYhZXQ2ygfT2Qjdg6iyeQVAyiz8okj88YRjy6NN"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("jtojtomepa8beP8AuQc6eXt5FriJwfFMwQx2v2f9mCL"),
+    ),
+    SpotMarketConfig(
+        symbol="dfdvSOL",
+        market_index=52,
+        oracle=Pubkey.from_string("EUQQD2fNN7h7su5TbWpUnf22zeGtF3RjEX2hgX2YPfLd"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("sctmB7GPi5L2Q5G9tUSzXvhZ4YiDMEGcRov9KfArQpx"),
+    ),
+    SpotMarketConfig(
+        symbol="sACRED-4",
+        market_index=53,
+        oracle=Pubkey.from_string("GheMfcCB49SuVCWrFReQDD2tLkcPDMG3qZEZWU44mHu"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("59CwZq5b6drmDizgGfxECG7f16hxDpG1nXrxPoQx4y8g"),
+    ),
+    SpotMarketConfig(
+        symbol="EURC",
+        market_index=54,
+        oracle=Pubkey.from_string("BkdSPLmw4W6twrJjAePw2bJAwDTBtxJ9t6LvNHfcBKg1"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
+        mint=Pubkey.from_string("HzwqbKZw8HxMN6bF2yFZNrht3c2iXXzpKcFu7uBEDKtr"),
+    ),
+    SpotMarketConfig(
+        symbol="PT-fragSOL-31OCT25-3",
+        market_index=55,
+        oracle=Pubkey.from_string("C41YpBLZfERAbV1p8DD48vDwbYhRQCbiryMx8Vp5sfo4"),
+        oracle_source=OracleSource.SwitchboardOnDemand(),  # type: ignore
+        mint=Pubkey.from_string("Aby6y5DYtTrhQD8i7JXLs4H3jdUTwSXDraYqnwn5tKbt"),
+    ),
+    SpotMarketConfig(
+        symbol="PUMP",
+        market_index=56,
+        oracle=Pubkey.from_string("5r8RWTaRiMgr9Lph3FTUE3sGb1vymhpCrm83Bovjfcps"),
+        oracle_source=OracleSource.PythLazer(),  # type: ignore
+        mint=Pubkey.from_string("pumpCmXqMfrsAkQ5r49WcJnRayYRqmXz6ae8H7H9Dfn"),
+    ),
+    SpotMarketConfig(
+        symbol="syrupUSDC",
+        market_index=57,
+        oracle=Pubkey.from_string("GqqkoqHU5pqgTvL88xSCipH9txbPETyzvAvybQ3zRpzw"),
+        oracle_source=OracleSource.PythPull(),  # type: ignore
+        mint=Pubkey.from_string("AvZZF1YaZDziPY2RCK4oJrRVrbN3mTD9NL24hPeaZeUj"),
+    ),
+    SpotMarketConfig(
+        symbol="LBTC",
+        market_index=58,
+        oracle=Pubkey.from_string("Fa3VKWbdb9yQ89vA9JfYnR6micY9LwGneoQ1So9JgXHT"),
+        oracle_source=OracleSource.PythPull(),  # type: ignore
+        mint=Pubkey.from_string("LBTCgU4b3wsFKsPwBn1rRZDx5DoFutM6RPiEt1TPDsY"),
+    ),
 ]
