@@ -148,7 +148,7 @@ def decode_user(buffer: bytes) -> UserAccount:
     orders: List[Order] = []
     for _ in range(32):
         # skip order if it's not open
-        if read_uint8(buffer, offset + 82) == 0:
+        if read_uint8(buffer, offset + 82) != 1:
             offset += 96
             continue
 
@@ -259,34 +259,40 @@ def decode_user(buffer: bytes) -> UserAccount:
 
         auction_duration = read_uint8(buffer, offset)
         offset += 1
-        offset += 3  # padding
+        posted_slot_tail = read_uint8(buffer, offset)
+        offset += 1
+        bit_flags = read_uint8(buffer, offset)
+        offset += 1
+        offset += 1  # padding
 
         orders.append(
             Order(
-                slot,
-                price,
-                base_asset_amount,
-                base_asset_amount_filled,
-                quote_asset_amount_filled,
-                trigger_price,
-                auction_start_price,
-                auction_end_price,
-                max_ts,
-                oracle_price_offset,
-                order_id,
-                market_index,
-                status,
-                order_type,
-                market_type,
-                user_order_id,
-                existing_position_direction,
-                direction,
-                reduce_only,
-                post_only,
-                immediate_or_cancel,
-                trigger_condition,
-                auction_duration,
-                [0, 0, 0],
+                slot=slot,
+                price=price,
+                base_asset_amount=base_asset_amount,
+                base_asset_amount_filled=base_asset_amount_filled,
+                quote_asset_amount_filled=quote_asset_amount_filled,
+                trigger_price=trigger_price,
+                auction_start_price=auction_start_price,
+                auction_end_price=auction_end_price,
+                max_ts=max_ts,
+                oracle_price_offset=oracle_price_offset,
+                order_id=order_id,
+                market_index=market_index,
+                status=status,
+                order_type=order_type,
+                market_type=market_type,
+                user_order_id=user_order_id,
+                existing_position_direction=existing_position_direction,
+                direction=direction,
+                reduce_only=reduce_only,
+                post_only=post_only,
+                immediate_or_cancel=immediate_or_cancel,
+                trigger_condition=trigger_condition,
+                auction_duration=auction_duration,
+                bit_flags=bit_flags,
+                posted_slot_tail=posted_slot_tail,
+                padding=[0],
             )
         )
 
@@ -354,11 +360,30 @@ def decode_user(buffer: bytes) -> UserAccount:
     margin_mode_num = read_uint8(buffer, offset)
     if margin_mode_num == 0:
         margin_mode = MarginMode.Default()
-    else:
+    elif margin_mode_num == 1:
         margin_mode = MarginMode.HighLeverage()
+    elif margin_mode_num == 2:
+        margin_mode = MarginMode.HighLeverageMaintenance()
+    else:
+        print(
+            f"Warning: unknown margin mode: {margin_mode_num}, (user: {authority}) returning default"
+        )
+        margin_mode = MarginMode.Default()
     offset += 1
 
-    padding = [0] * 21
+    pool_id = read_uint8(buffer, offset)
+    offset += 1
+
+    padding1_bytes = [buffer[offset + i] for i in range(3)]
+    offset += 3
+
+    last_fuel_bonus_update_ts = read_int32_le(buffer, offset, signed=False)
+    offset += 4
+
+    final_padding_bytes = [buffer[offset + i] for i in range(12)]
+    offset += 12
+
+    user_account_padding = padding1_bytes + final_padding_bytes
 
     return UserAccount(
         authority,
@@ -388,5 +413,7 @@ def decode_user(buffer: bytes) -> UserAccount:
         open_auctions,
         has_open_auction,
         margin_mode,
-        padding,
+        pool_id,
+        last_fuel_bonus_update_ts,
+        user_account_padding,
     )
