@@ -1,17 +1,15 @@
 import asyncio
-from solana.rpc.async_api import AsyncClient
-from solana.rpc.commitment import Commitment
-from solana.rpc.websocket_api import SolanaWsClientProtocol
-from solders.pubkey import Pubkey
-from solders.rpc.config import RpcTransactionLogsFilterMentions
-
-from solana.rpc.websocket_api import connect
-
 from typing import cast
 
 import websockets.exceptions
+from solana.rpc.async_api import AsyncClient
+from solana.rpc.commitment import Commitment
+from solana.rpc.websocket_api import SolanaWsClientProtocol, connect
+from solders.pubkey import Pubkey
+from solders.rpc.config import RpcTransactionLogsFilterMentions
 
-from driftpy.events.types import LogProviderCallback, LogProvider
+from driftpy.events.types import LogProvider, LogProviderCallback
+from driftpy.types import get_ws_url
 
 
 class WebsocketLogProvider(LogProvider):
@@ -29,7 +27,11 @@ class WebsocketLogProvider(LogProvider):
 
     async def subscribe_ws(self, callback: LogProviderCallback):
         endpoint = self.connection._provider.endpoint_uri
-        ws_endpoint = endpoint.replace("https", "wss").replace("http", "ws")
+        if endpoint.startswith("http"):
+            ws_endpoint = get_ws_url(endpoint)
+        else:
+            ws_endpoint = endpoint
+
         async for ws in connect(ws_endpoint):
             ws: SolanaWsClientProtocol
             try:
