@@ -1,12 +1,11 @@
 from abc import abstractmethod
 from dataclasses import dataclass
-from typing import Union, Sequence, Optional
+from typing import Optional, Sequence
 
 from solders.address_lookup_table_account import AddressLookupTableAccount
+from solders.instruction import Instruction
 from solders.keypair import Keypair
 from solders.signature import Signature
-from solders.instruction import Instruction
-from solana.transaction import Transaction
 from solders.transaction import VersionedTransaction
 
 
@@ -17,15 +16,6 @@ class TxSigAndSlot:
 
 
 class TxSender:
-    @abstractmethod
-    async def get_legacy_tx(
-        self,
-        ixs: Sequence[Instruction],
-        payer: Keypair,
-        additional_signers: Optional[Sequence[Keypair]],
-    ) -> Transaction:
-        pass
-
     @abstractmethod
     async def get_versioned_tx(
         self,
@@ -37,5 +27,5 @@ class TxSender:
         pass
 
     @abstractmethod
-    async def send(self, tx: Union[Transaction, VersionedTransaction]) -> TxSigAndSlot:
+    async def send(self, tx: VersionedTransaction) -> TxSigAndSlot:
         pass
