@@ -1,7 +1,7 @@
 import inspect
 import zlib
 from dataclasses import dataclass, field
-from typing import Optional, TypedDict
+from typing import Callable, Optional, TypedDict
 from urllib.parse import urlparse, urlunparse
 
 from borsh_construct.enum import _rust_enum
@@ -253,6 +253,7 @@ class OracleSource:
     PythLazer = constructor()
     PythLazer1K = constructor()
     PythLazer1M = constructor()
+    PythLazerStableCoin = constructor()
 
 
 @_rust_enum
@@ -351,6 +352,7 @@ class UserStatus:
 class MarginMode:
     Default = constructor()
     HighLeverage = constructor()
+    HighLeverageMaintenance = constructor()
 
 
 @_rust_enum
@@ -375,6 +377,9 @@ class OracleSourceNum:
     PYTH_STABLE_COIN_PULL = 9
     SWITCHBOARD_ON_DEMAND = 11
     PYTH_LAZER = 12
+    PYTH_LAZER_1K = 13
+    PYTH_LAZER_1M = 14
+    PYTH_LAZER_STABLE_COIN = 15
 
 
 @_rust_enum
@@ -427,7 +432,7 @@ class OrderParams:
     price: int = 0
     reduce_only: bool = False
     post_only: PostOnlyParams = field(default_factory=PostOnlyParams.NONE)
-    immediate_or_cancel: bool = False
+    bit_flags: int = 0
     max_ts: Optional[int] = None
     trigger_price: Optional[int] = None
     trigger_condition: OrderTriggerCondition = field(
@@ -449,6 +454,23 @@ class OrderParams:
             raise ValueError("market type not set on order params")
 
 
+class OrderParamsBitFlag:
+    """Bit flags for OrderParams.bit_flags field"""
+
+    IMMEDIATE_OR_CANCEL = 1 << 0
+    UPDATE_HIGH_LEVERAGE_MODE = 1 << 1
+
+    @staticmethod
+    def is_immediate_or_cancel(bit_flags: int) -> bool:
+        """Check if IMMEDIATE_OR_CANCEL flag is set"""
+        return (bit_flags & OrderParamsBitFlag.IMMEDIATE_OR_CANCEL) != 0
+
+    @staticmethod
+    def is_update_high_leverage_mode(bit_flags: int) -> bool:
+        """Check if UPDATE_HIGH_LEVERAGE_MODE flag is set"""
+        return (bit_flags & OrderParamsBitFlag.UPDATE_HIGH_LEVERAGE_MODE) != 0
+
+
 @dataclass
 class ModifyOrderParams:
     direction: Optional[PositionDirection] = None
@@ -456,7 +478,7 @@ class ModifyOrderParams:
     price: Optional[int] = None
     reduce_only: Optional[bool] = None
     post_only: Optional[PostOnlyParams] = None
-    immediate_or_cancel: Optional[bool] = None
+    bit_flags: Optional[int] = None
     max_ts: Optional[int] = None
     trigger_price: Optional[int] = None
     trigger_condition: Optional[OrderTriggerCondition] = None
@@ -563,10 +585,14 @@ class AMM:
     last_oracle_valid: bool
     target_base_asset_amount_per_lp: int
     per_lp_base: int
-    padding1: int = 0
-    padding2: int = 0
-    total_fee_earned_per_lp: Optional[int] = None
-    padding: list[int] = field(default_factory=lambda: [0] * 12)
+    total_fee_earned_per_lp: int
+    net_unsettled_funding_pnl: int
+    quote_asset_amount_with_unsettled_lp: int
+    reference_price_offset: int
+    taker_speed_bump_override: int
+    amm_spread_adjustment: int
+    amm_inventory_spread_adjustment: int
+    padding: list[int] = field(default_factory=lambda: [0] * 14)
 
 
 @dataclass
@@ -653,7 +679,9 @@ class Order:
     immediate_or_cancel: bool
     trigger_condition: OrderTriggerCondition
     auction_duration: int
-    padding: list[int] = field(default_factory=lambda: [0] * 3)
+    posted_slot_tail: int
+    bit_flags: int
+    padding: list[int] = field(default_factory=lambda: [0] * 1)
 
 
 @dataclass
@@ -725,13 +753,19 @@ class PerpMarketAccount:
     status: MarketStatus
     contract_type: ContractType
     contract_tier: ContractTier
-    padding1: int = 0
-    quote_spot_market_index: Optional[int] = None
-    fee_adjustment: Optional[int] = None
-    fuel_boost_taker: Optional[int] = None
-    fuel_boost_maker: Optional[int] = None
-    fuel_boost_position: Optional[int] = None
-    padding: list[int] = field(default_factory=lambda: [0] * 43)
+    paused_operations: int
+    quote_spot_market_index: int
+    fee_adjustment: int
+
+    fuel_boost_taker: int
+    fuel_boost_maker: int
+    fuel_boost_position: int
+
+    pool_id: int
+    high_leverage_margin_ratio_initial: int
+    high_leverage_margin_ratio_maintenance: int
+
+    padding: list[int] = field(default_factory=lambda: [0] * 38)
 
 
 @dataclass
@@ -898,12 +932,14 @@ class UserAccount:
     open_auctions: int
     has_open_auction: bool
     margin_mode: MarginMode
-    padding: list[int] = field(default_factory=lambda: [0] * 21)
+    pool_id: int
+    last_fuel_bonus_update_ts: int
+    padding: list[int] = field(default_factory=lambda: [0] * 15)
 
 
 @dataclass
 class PickledData:
-    pubkey: Pubkey
+    pubkey: str
     data: bytes
 
 
@@ -923,26 +959,26 @@ class UserStatsAccount:
     referrer: Pubkey
     fees: UserFees
     next_epoch_ts: int
-    maker_volume30d: int
-    taker_volume30d: int
-    filler_volume30d: int
-    last_maker_volume30d_ts: int
-    last_taker_volume30d_ts: int
-    last_filler_volume30d_ts: int
+    maker_volume_30d: int
+    taker_volume_30d: int
+    filler_volume_30d: int
+    last_maker_volume_30d_ts: int
+    last_taker_volume_30d_ts: int
+    last_filler_volume_30d_ts: int
     if_staked_quote_asset_amount: int
     number_of_sub_accounts: int
     number_of_sub_accounts_created: int
     is_referrer: bool
     disable_update_perp_bid_ask_twap: bool
-    padding1: list[int] = (field(default_factory=lambda: [0] * 2),)
-    last_fuel_bonus_update_ts: int = (0,)
-    fuel_insurance: int = (0,)
-    fuel_deposits: int = (0,)
-    fuel_borrows: int = (0,)
-    fuel_positions: int = (0,)
-    fuel_taker: int = (0,)
-    fuel_maker: int = (0,)
-    if_staked_gov_token_amount: int = (0,)
+    fuel_overflow_status: int = 0
+    fuel_insurance: int = 0
+    fuel_deposits: int = 0
+    fuel_borrows: int = 0
+    fuel_positions: int = 0
+    fuel_taker: int = 0
+    fuel_maker: int = 0
+    if_staked_gov_token_amount: int = 0
+    last_fuel_if_bonus_update_ts: int = 0
     padding: list[int] = field(default_factory=lambda: [0] * 12)
 
 
@@ -1032,6 +1068,24 @@ class ProtocolIfSharesTransferConfigAccount:
     padding: list[int] = field(default_factory=lambda: [0] * 8)
 
 
+@dataclass
+class IfRebalanceConfigAccount:
+    pubkey: Pubkey
+    total_in_amount: int
+    current_in_amount: int
+    current_out_amount: int
+    current_in_amount_since_last_transfer: int
+    epoch_start_ts: int
+    epoch_in_amount: int
+    epoch_max_in_amount: int
+    epoch_duration: int
+    out_market_index: int
+    in_market_index: int
+    max_slippage_bps: int
+    swap_mode: int
+    status: int
+
+
 @dataclass
 class ReferrerNameAccount:
     authority: Pubkey
@@ -1232,69 +1286,6 @@ class FundingPaymentRecord:
     amm_cumulative_funding_short: int
 
 
-@dataclass
-class LiquidatePerpRecord:
-    market_index: int
-    oracle_price: int
-    base_asset_amount: int
-    quote_asset_amount: int
-    lp_shares: int
-    user_order_id: int
-    liquidator_order_id: int
-    fill_record_id: int
-    liquidator_fee: int
-    if_fee: int
-
-
-@dataclass
-class LiquidateSpotRecord:
-    asset_market_index: int
-    asset_price: int
-    asset_transfer: int
-    liability_market_index: int
-    liability_price: int
-    liability_transfer: int
-    if_fee: int
-
-
-@dataclass
-class LiquidateBorrowForPerpPnlRecord:
-    perp_market_index: int
-    market_oracle_price: int
-    pnl_transfer: int
-    liability_market_index: int
-    liability_price: int
-    liability_transfer: int
-
-
-@dataclass
-class LiquidatePerpPnlForDepositRecord:
-    perp_market_index: int
-    market_oracle_price: int
-    pnl_transfer: int
-    asset_market_index: int
-    asset_price: int
-    asset_transfer: int
-
-
-@dataclass
-class PerpBankruptcyRecord:
-    market_index: int
-    pnl: int
-    if_payment: int
-    clawback_user: Pubkey
-    clawback_user_payment: int
-    cumulative_funding_rate_delta: int
-
-
-@dataclass
-class SpotBankruptcyRecord:
-    market_index: int
-    borrow_amount: int
-    cumulative_deposit_interest_delta: int
-    if_payment: int
-
-
 @dataclass
 class LiquidationRecord:
     ts: int
@@ -1380,6 +1371,42 @@ class SwapRecord:
     fee: int
 
 
+@dataclass
+class InsuranceFundSwapRecord:
+    rebalance_config: Pubkey
+    in_if_total_shares_before: int
+    out_if_total_shares_before: int
+    in_if_user_shares_before: int
+    out_if_user_shares_before: int
+    in_if_total_shares_after: int
+    out_if_total_shares_after: int
+    in_if_user_shares_after: int
+    out_if_user_shares_after: int
+    ts: int
+    in_amount: int
+    out_amount: int
+    out_oracle_price: int
+    out_oracle_price_twap: int
+    in_vault_amount_before: int
+    out_vault_amount_before: int
+    in_fund_vault_amount_after: int
+    out_fund_vault_amount_after: int
+    in_market_index: int
+    out_market_index: int
+
+
+@dataclass
+class TransferProtocolIfSharesToRevenuePoolRecord:
+    ts: int
+    market_index: int
+    amount: int
+    shares: int
+    if_vault_amount_before: int
+    protocol_shares_before: int
+    protocol_shares_after: int
+    current_in_amount_since_last_transfer: int
+
+
 @dataclass
 class PrelaunchOracleParams:
     perp_market_index: int
@@ -1387,6 +1414,18 @@ class PrelaunchOracleParams:
     max_price: Optional[int]
 
 
+@dataclass
+class IfRebalanceConfigParams:
+    total_in_amount: int
+    epoch_max_in_amount: int
+    epoch_duration: int
+    out_market_index: int
+    in_market_index: int
+    max_slippage_bps: int
+    swap_mode: int
+    status: int
+
+
 @dataclass
 class PrelaunchOracle:
     price: int
@@ -1448,22 +1487,47 @@ class OptionalOrderParams(TypedDict, total=False):
 
 
 @dataclass
-class SignedSwiftOrderParams:
+class SignedMsgOrderParams:
     order_params: bytes
     signature: bytes
 
 
 @dataclass
-class SwiftTriggerOrderParams:
+class SignedMsgTriggerOrderParams:
     trigger_price: int
     base_asset_amount: int
 
 
 @dataclass
-class SwiftOrderParamsMessage:
-    swift_order_params: OptionalOrderParams
+class SignedMsgOrderParamsMessage:
+    signed_msg_order_params: OptionalOrderParams
     sub_account_id: int
     slot: int
     uuid: bytes
-    take_profit_order_params: SwiftTriggerOrderParams | None
-    stop_loss_order_params: SwiftTriggerOrderParams | None
+    take_profit_order_params: SignedMsgTriggerOrderParams | None
+    stop_loss_order_params: SignedMsgTriggerOrderParams | None
+
+
+@dataclass
+class SignedMsgOrderParamsDelegateMessage:
+    signed_msg_order_params: OptionalOrderParams
+    slot: int
+    uuid: bytes
+    taker_pubkey: Pubkey
+    take_profit_order_params: SignedMsgTriggerOrderParams | None
+    stop_loss_order_params: SignedMsgTriggerOrderParams | None
+
+
+class OrderBitFlag:
+    SignedMessage = 1
+    OracleTriggerMarket = 2
+    SafeTriggerOrder = 4
+
+
+@dataclass
+class GrpcLogProviderConfig:
+    endpoint: str
+    token: str
+
+
+LogProviderCallback = Callable[[any, int, list[str]], None]
